<style>
  /* Display the full TOC */
  nav {
    column-count: auto;
    -moz-column-count: auto;
    -webkit-column-count: auto;
  }
  nav ul ul {
    display: block;
    padding-left: 2em;
  }
  #influences blockquote p:last-child {
    color: #999;
  }
</style>
