#include <stdint.h>
#include <assert.h>

/* This is the code generated by cbindgen 0.12.1 for the `enum TT`
 * type in nonclike.rs . */
enum TT_Tag {
  AA,
  BB,
};
typedef uint8_t TT_Tag;

typedef struct {
  uint64_t _0;
  uint64_t _1;
} AA_Body;

typedef struct {
  TT_Tag tag;
  union {
    AA_Body aa;
  };
} TT;

/* This is the code generated by cbindgen 0.12.1 for the `enum T` type
 * in nonclike.rs . */
enum T_Tag {
  A,
  B,
};
typedef uint8_t T_Tag;

typedef struct {
  uint64_t _0;
} A_Body;

typedef struct {
  T_Tag tag;
  union {
    A_Body a;
  };
} T;

/* These symbols are defined by the Rust staticlib built from
 * nonclike.rs. */
extern TT tt_new(uint64_t a, uint64_t b);
extern T t_new(uint64_t v);

int main(int argc, char *argv[]) {
  (void)argc; (void)argv;

  /* This example works. */
  TT tt = tt_new(10, 20);
  assert(AA == tt.tag);
  assert(10 == tt.aa._0);
  assert(20 == tt.aa._1);

  /* This one used to segfault (see issue #68190). */
  T t = t_new(10);
  assert(A == t.tag);
  assert(10 == t.a._0);

  return 0;
}
